@@ -199,7 +199,11 @@ class KinMS:
 
         self.ra = ra 
         self.dec = dec
-        self.seed = seed or np.array([100, 101, 102, 103], dtype='int')
+        if seed != None:
+            self.seed = seed*np.array([100, 101, 102, 103], dtype='int')
+        else:
+            self.seed = np.array([100, 101, 102, 103], dtype='int')
+        self.fixSeed = fixSeed
         self.intFlux = intFlux or 0
         self.vSys = vSys or 0
         self.phaseCent = np.array(phaseCent) 
@@ -207,7 +211,7 @@ class KinMS:
         self.vPhaseCent = np.array(vPhaseCent) 
         self.restFreq = restFreq or  230.542e9
         self.fileName = fileName
-        self.fixSeed = fixSeed
+
         self.cleanOut = cleanOut
         self.returnClouds = returnClouds
         self.huge_beam = huge_beam
@@ -491,7 +495,7 @@ class KinMS:
             print('Generating cloudlets,', end =' ')
 
         if not fixSeed:
-            seed = (np.random.uniform(0, 1000, 1)*[1,3,5,17]).astype('int')
+            seed = np.random.randint(1, 100)*np.array([1,3,5,9])
         else:
             seed = self.seed
         
@@ -519,7 +523,7 @@ class KinMS:
             else:
                 diskThick_here = diskThick
                 if self.verbose: print('Using an exponential scale height of ' + str(diskThick) + '.')
-            rng3 = np.random.RandomState(seed[3])
+            rng3 = np.random.RandomState(seed[2])
             z_pos = diskThick_here * rng3.exponential(1,nSamps)*rng3.choice([-1,1],size=nSamps)
         else:
             if self.verbose: print('Using a thin disc assumption.')
@@ -569,7 +573,7 @@ class KinMS:
             r_flatv = self.r_flat
         
         if not self.fixSeed:
-            seed = np.random.uniform(0, 100, 4).astype('int')
+            seed = np.random.randint(100, 200)*np.array([17,14,21,102])
         else:
             seed = self.seed
                                                                 
